*Personalizing code
global logpath = "********"
global outpath = "********"
global username = "********"
global password = "********"

*Starting log file
clear
capture log close
log using ${logpath}variabilityofprices.log, replace

*Loading raw data
odbc load, exec("select * FROM HCCI_2.OP_SDDV2 os WHERE proc_cd ='90999' AND rvnu_cd ='0821' AND primary_cov_ind ='1' AND esi_flag='1' AND over65_flag='0' AND tob='721' AND pos='65';") dsn("Vertica") user("${username}") password("${password}")

*Limiting sample to single-session claims
gen lengthoftime=lst_dt-fst_dt+1
gen oneday=lengthoftime==1 if !missing(lengthoftime)
gen oneunit=units==1 if !missing(units)
keep if oneunit==1 & oneday==1

*Limiting sample to first 33 months of dialysis
gen date_start=mofd(fst_dt)
gen date_end=mofd(lst_dt)
bysort z_patid: egen dial_startdate=min(date_start)
gen month_on_dial=date_end-dial_startdate
keep if month_on_dial<=33

*Limiting sample to patient-months with fewer than 15 treatments
bysort z_patid yr mnth: egen month_treats=count(z_patid)
keep if month_treats<=14

*Dropping unnecessary variables
keep yr mnth calc_allwd z_patid hnpi prov_state

*Destringing numerical variables
foreach var in yr mnth {
	destring `var', replace force
}

*Limiting sample to claims with positive payment amounts
gen HD_price=calc_allwd if calc_allwd>0

*Dropping the top 1% of prices
su HD_price, d
replace HD_price=. if HD_price>`r(p99)'
keep if !missing(HD_price)

*Creating time variable
gen t=ym(yr,mnth)
format t %tm

*Inputing Medicare base rate information
gen medicare=235.27 if t>707
replace medicare=232.37 if t>695 & t<=707
replace medicare=231.55 if t>683 & t<=695
replace medicare=230.39 if t>671 & t<=683
replace medicare=239.43 if t>659 & t<=671
replace medicare=239.02 if t>647 & t<=659
replace medicare=240.36 if t>635 & t<=647
replace medicare=234.52 if t>623 & t<=635

*Inputing maximum Medicare adjustments
gen max_comorbidity_adj=1.017*1.257*1.04*1.082*1.192*1.095*1.239 if t>671 // Age, BMI, comorbidities, and low volume adjustments
replace max_comorbidity_adj=1.025*1.171*1.114*1.135*1.183*1.072*1.099*1.024*1.189 if t<=671
gen max_geo_adj=1.9025 if t>707 // Geographic Wage Adjustment
replace max_geo_adj=1.7931  if t>695 & t<=707
replace max_geo_adj=1.8017  if t>683 & t<=695
replace max_geo_adj=1.7771  if t>671 & t<=683
replace max_geo_adj=1.7239  if t>659 & t<=671
replace max_geo_adj=1.7276  if t>647 & t<=659
replace max_geo_adj=1.7471  if t>635 & t<=647
replace max_geo_adj=1.6996  if t>623 & t<=635
gen max_medicare=medicare*max_comorbidity_adj*max_geo_adj // Maximum Medicare rate

*Inputing minimum Medicare adjustments
gen min_geo_adj=0.3711 if t>707 // Geographic Wage Adjustment
replace min_geo_adj=0.3845  if t>695 & t<=707
replace min_geo_adj=0.3875  if t>683 & t<=695
replace min_geo_adj=0.3888  if t>671 & t<=683
replace min_geo_adj=0.3978  if t>659 & t<=671
replace min_geo_adj=0.3872  if t>647 & t<=659
replace min_geo_adj=0.3963  if t>635 & t<=647
replace min_geo_adj=0.3912  if t>623 & t<=635
gen min_medicare=medicare*min_geo_adj // Minimum Medicare rate

*Getting counts of unique claims, patients, and providers reported in methods and supplementary materials
codebook z_patid hnpi

*Getting summary statistics reported in first paragraph of results
su HD_price, d
su medicare max_medicare
su HD_price if HD_price>2000
su HD_price if HD_price>3000

*Getting statistics reported in second paragraph of results
centile HD_price if t==624
centile HD_price if t==719
su medicare max_medicare if t==624
su medicare max_medicare if t==719

*Creating Figure
preserve
	collapse (mean) mean_price=HD_price *medicare ///
		(p10) price_p10=HD_price (p50) price_q2=HD_price ///
		(p90) price_p90=HD_price (count) obs=HD_price, by(t) // Collapsing to month level
	twoway  (rarea price_p10 price_p90 t, color(eltblue%30)) ///
			(line price_q2 t, color(edkblue) lpatt(solid)) ///
			(line medicare t, color(edkblue) lpatt(dash)) ///
			(line max_medicare t, color(edkblue) lpatt(dot)) ///
			(line min_medicare t, color(edkblue) lpatt(dot)), ///
			yti("Price Per Hemodialysis Session ($)", size(small)) xti("") ///
			ylab(,format(%12.0gc) angle(0) labsize(small)) 	///
			xlab(624 "2012" 648 "2014" 672 "2016" 696 "2018" 720 "2020", labsize(small)) ///
			leg(order(1 "10-90 Pct. Private Price Range" 2 "Median Private Price" ///
				3 "Medicare Base Rate" 4 "Max. and Min. Medicare Rate") size(small)) ///
			plotregion(fcolor(white)) graphregion(fcolor(white)) 
	graph export "${outpath}timeseries.pdf", as(pdf) replace
	export excel using "${outpath}timeseries.xlsx", firstrow(variables) replace
restore

*Getting summary statistics report in third paragraph of results
su HD_price if prov_state=="AR"
su HD_price if prov_state=="WV"

*Creating Table
preserve
	collapse (mean) mean=HD_price (sd) sd=HD_price ///
		(count) obs=HD_price, by(prov_state) // Collapsing to state level
	drop if missing(prov_state) | obs<1500 | prov_state=="AL" // Dropping if we cannot report data
	gsort -mean
	gen price_rank=_n // Getting price ranking
	export excel using "${outpath}statelevel.xlsx", firstrow(variables) replace
restore